@@ -7,11 +7,12 @@ app = Flask(__name__)
 
 def main():
     try:
-        with open("~/.elastictex", "r") as f:
+        with open("./.elastictex", "r") as f:
             host = f.read().strip()
     except:
         host = "localhost:9200"
 
+    print(host)
     api.init(host)
     app.run(debug=True)
 
